==> openorienteering-mapper_0.8.4.orig.tar.gz: mapper-0.8.4/README.md <==
# OpenOrienteering Mapper

![Mapper Screenshot](https://www.openorienteering.org/mapper-manual/pages/images/main_window.png)

OpenOrienteering Mapper is an orienteering mapmaking program and provides
a free and open source alternative to existing commercial software.
OpenOrienteering Mapper runs on Android, Windows, Mac OS X and Linux.

 - [Mapper Homepage](https://www.openorienteering.org/apps/mapper/)
 - [Manual](https://www.openorienteering.org/mapper-manual/)
 - [Downloads](https://github.com/OpenOrienteering/mapper/releases)
 - [OpenOrienteering Blog](https://www.openorienteering.org/)


## Reporting Issues and Asking for Help

Issues and possible improvements can be posted to our public [Ticket system](https://github.com/OpenOrienteering/mapper/issues).
Please make sure you provide all relevant information about your problem or idea.


## Contributing

### Translating

Translations can be edited online on [Weblate](https://hosted.weblate.org/projects/openorienteering/mapper/). You can register/login with your Github account. Find out more about translation in our [wiki](https://github.com/OpenOrienteering/mapper/wiki/Translation).


### Writing Documentation

The Mapper manual lives in its [own repository](https://github.com/OpenOrienteering/mapper-manual)
which contains all information for you to get started.


### Writing Code

For building Mapper from source see [`INSTALL.md`](https://github.com/OpenOrienteering/mapper/blob/master/INSTALL.md).
Pull requests are very welcome.

 - [Issue tracker](https://github.com/OpenOrienteering/mapper/issues)
 - [API documentation](https://www.openorienteering.org/api-docs/mapper/)
 - [Developer wiki](https://github.com/OpenOrienteering/mapper/wiki)


## License

Mapper is licensed under the [GNU GENERAL PUBLIC LICENSE Version 3](https://www.gnu.org/licenses/gpl.html).

==> openorienteering-mapper_0.9.4.orig.tar.gz: mapper-0.9.4/README.md <==
# OpenOrienteering Mapper

![Mapper Screenshot](https://www.openorienteering.org/mapper-manual/pages/images/main_window.png)

OpenOrienteering Mapper is an orienteering mapmaking program and provides
a free and open source alternative to existing commercial software.
OpenOrienteering Mapper runs on Android, Windows, macOS and Linux.

 - [Mapper Homepage](https://www.openorienteering.org/apps/mapper/)
 - [Manual](https://www.openorienteering.org/mapper-manual/)
 - [Downloads](https://github.com/OpenOrienteering/mapper/releases)
 - [OpenOrienteering Blog](https://www.openorienteering.org/)


## Reporting Issues and Asking for Help

Issues and possible improvements can be posted to our public [Ticket system](https://github.com/OpenOrienteering/mapper/issues).
Please make sure you provide all relevant information about your problem or idea.


## Contributing

### Translating

Translations can be edited online on [Weblate](https://hosted.weblate.org/projects/openorienteering/mapper/). You can register/login with your Github account. Find out more about translation in our [wiki](https://github.com/OpenOrienteering/mapper/wiki/Translation).


### Writing Documentation

The Mapper manual lives in its [own repository](https://github.com/OpenOrienteering/mapper-manual)
which contains all information for you to get started.


### Writing Code

For building Mapper from source see [`INSTALL.md`](https://github.com/OpenOrienteering/mapper/blob/master/INSTALL.md).
Pull requests are very welcome.

 - [Issue tracker](https://github.com/OpenOrienteering/mapper/issues)
 - [API documentation](https://www.openorienteering.org/api-docs/mapper/)
 - [Developer wiki](https://github.com/OpenOrienteering/mapper/wiki)


## License

Mapper is licensed under the [GNU GENERAL PUBLIC LICENSE Version 3](https://www.gnu.org/licenses/gpl.html).
